#!/usr/bin/python

import os
import os.path
from fnmatch import fnmatch
import shutil
import subprocess

def createcursors(inputdir, outputdir):
    """Runs icon-slicer for a directory.

    NOTE: changes the current directory to inputdir.
    """
    # run iconslicer for each config found
    os.chdir(inputdir)
    isconfig = lambda x: fnmatch(x, "*.xml")
    for file in filter(isconfig, os.listdir(inputdir)):
        subprocess.call(["icon-slicer", "--output-dir=%s" % outputdir,
                         os.path.join(inputdir, file)])


# get the root directory (so we can change it back)
currentdir = os.getcwd()
bindir = os.path.join(currentdir, "bin")
srcdir = os.path.join(currentdir, "src")
shareddir = os.path.join(srcdir, "Shared")

# create bin directory if not present
if not os.path.isdir(bindir):
    os.mkdir(bindir)

themes = ["WiiCcwCursorTheme", "WiiCursorTheme"]

for theme in themes:
    # make sure output directory exists
    themeoutput = os.path.join(bindir, theme)
    if not os.path.isdir(themeoutput):
        os.mkdir(themeoutput)

    # run iconslicer for theme specific and shared cursors
    themeinput = os.path.join(srcdir, theme)
    createcursors(themeinput, themeoutput)
    createcursors(shareddir, themeoutput)

    # copy README and theme file to output
    shutil.copy(os.path.join(themeinput, "readme.txt"), themeoutput)
    shutil.copy(os.path.join(themeinput, "index.theme"), themeoutput)

# TODO: create a tar file of the cursor theme
# tar cjf ../WiiCursorTheme.tar.bz2 --exclude=\.bzr ./

